@@ -35,6 +35,9 @@ CDBERROR_TASKERROR = 'CdbError.TaskError'
 # Async task exception.
 FAILEDOPERATION_ASYNCTASKSTATUSERROR = 'FailedOperation.AsyncTaskStatusError'
 
+# Failed to lock the instance while performing exclusive operations. Please try again later.
+FAILEDOPERATION_CDBINSTANCELOCKFAILERROR = 'FailedOperation.CdbInstanceLockFailError'
+
 # Creation failed. Please check whether the user already exists.
 FAILEDOPERATION_CREATEACCOUNTERROR = 'FailedOperation.CreateAccountError'
 
@@ -47,6 +50,9 @@ FAILEDOPERATION_DBOPERATIONACTIONERROR = 'FailedOperation.DBOperationActionError
 # An error occurred while obtaining permissions.
 FAILEDOPERATION_GETPRIVILEGEERROR = 'FailedOperation.GetPrivilegeError'
 
+# Query failed.
+FAILEDOPERATION_INSTANCEQUERYERROR = 'FailedOperation.InstanceQueryError'
+
 # Failed to deserialize JSON.
 FAILEDOPERATION_JSONUNMARSHALERROR = 'FailedOperation.JsonUnmarshalError'
 
@@ -83,6 +89,9 @@ INTERNALERROR_ASYNCREQUESTERROR = 'InternalError.AsyncRequestError'
 # Authentication failed.
 INTERNALERROR_AUTHERROR = 'InternalError.AuthError'
 
+# Authentication failed.
+INTERNALERROR_CAUTHERROR = 'InternalError.CauthError'
+
 # Internal system error.
 INTERNALERROR_CDBCGWERROR = 'InternalError.CdbCgwError'
 
@@ -188,6 +197,9 @@ INVALIDPARAMETER_CONTROLLERNOTFOUNDERROR = 'InvalidParameter.ControllerNotFoundE
 # There are resources in the placement group.
 INVALIDPARAMETER_DEPLOYGROUPNOTEMPTY = 'InvalidParameter.DeployGroupNotEmpty'
 
+# Parameter exception.
+INVALIDPARAMETER_EXCEPTIONPARAM = 'InvalidParameter.ExceptionParam'
+
 # The instance is not found.
 INVALIDPARAMETER_INSTANCENAMENOTFOUND = 'InvalidParameter.InstanceNameNotFound'
 
@@ -203,7 +215,7 @@ INVALIDPARAMETER_INVALIDNAME = 'InvalidParameter.InvalidName'
 # Invalid parameter value
 INVALIDPARAMETER_INVALIDPARAMETERERROR = 'InvalidParameter.InvalidParameterError'
 
-# 
+# Failed to deserialize JSON.
 INVALIDPARAMETER_JSONUNMARSHALERROR = 'InvalidParameter.JsonUnmarshalError'
 
 # The quota of placement group resources has been exceeded.
@@ -290,18 +302,33 @@ OPERATIONDENIED_DELETEROOTACCOUNTERROR = 'OperationDenied.DeleteRootAccountError
 # This instance needs permissions to use this feature.
 OPERATIONDENIED_FUNCTIONDENIED = 'OperationDenied.FunctionDenied'
 
+# Instance locks are in conflict. Please try again later.
+OPERATIONDENIED_INSTANCELOCKERCONFLICT = 'OperationDenied.InstanceLockerConflict'
+
 # Exceptional instance status
 OPERATIONDENIED_INSTANCESTATUSERROR = 'OperationDenied.InstanceStatusError'
 
 # Delayed replication is not allowed because the instance is executing another task.
 OPERATIONDENIED_INSTANCETASKRUNNING = 'OperationDenied.InstanceTaskRunning'
 
+# The instance does not support this operation.
+OPERATIONDENIED_INSTANCEUNSUPPORTEDOPERATEERROR = 'OperationDenied.InstanceUnsupportedOperateError'
+
+# Basic instances do not support this operation (feature).
+OPERATIONDENIED_NOTSUPPORTBASIC = 'OperationDenied.NotSupportBasic'
+
 # The host information of the local root account cannot be modified.
 OPERATIONDENIED_NOTSUPPORTMODIFYLOCALROOTHOSTERROR = 'OperationDenied.NotSupportModifyLocalRootHostError'
 
 # There are other orders being submitted. Please try again later.
 OPERATIONDENIED_OTHERODERINPROCESS = 'OperationDenied.OtherOderInProcess'
 
+# The maximum number of results has been reached. Please narrow down your query.
+OPERATIONDENIED_RESULTOVERLIMIT = 'OperationDenied.ResultOverLimit'
+
+# The Tencent Cloud sub-account is not allowed to perform the operation due to insufficient permissions.
+OPERATIONDENIED_SUBACCOUNTOPERATIONDENIED = 'OperationDenied.SubAccountOperationDenied'
+
 # This instance is not refundable.
 OPERATIONDENIED_UNSUPPORTREFUNDERROR = 'OperationDenied.UnSupportRefundError'
 
