@@ -18,27 +18,27 @@ import warnings
 from tencentcloud.common.abstract_model import AbstractModel
 
 
-class ChannelInfo(AbstractModel):
-    """Channel information.
+class CacheInfo(AbstractModel):
+    """Cache configuration
 
     """
 
     def __init__(self):
+        r"""
+        :param Info: List of timeout parameter configuration
+Note: this field may return `null`, indicating that no valid value was found.
+        :type Info: list of CacheInfoInfo
         """
-        :param Id: Channel ID.\n        :type Id: str\n        :param Name: Channel name.\n        :type Name: str\n        :param Protocol: Channel protocol.\n        :type Protocol: str\n        :param Points: Channel input and output.\n        :type Points: :class:`tencentcloud.mdp.v20200527.models.PointInfo`\n        """
-        self.Id = None
-        self.Name = None
-        self.Protocol = None
-        self.Points = None
+        self.Info = None
 
 
     def _deserialize(self, params):
-        self.Id = params.get("Id")
-        self.Name = params.get("Name")
-        self.Protocol = params.get("Protocol")
-        if params.get("Points") is not None:
-            self.Points = PointInfo()
-            self.Points._deserialize(params.get("Points"))
+        if params.get("Info") is not None:
+            self.Info = []
+            for item in params.get("Info"):
+                obj = CacheInfoInfo()
+                obj._deserialize(item)
+                self.Info.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -48,14 +48,96 @@ class ChannelInfo(AbstractModel):
         
 
 
-class CreateMediaPackageChannelEndpointRequest(AbstractModel):
-    """CreateMediaPackageChannelEndpoint request structure.
+class CacheInfoInfo(AbstractModel):
+    """Timeout information for cache configuration
 
     """
 
     def __init__(self):
+        r"""
+        :param Timeout: Timeout period (ms), which must be an integer multiple of 1000
+.m3u8/.mpd: [1000, 60000]
+.ts/.m4s/.mp4: [10000, 1800000]
+        :type Timeout: int
+        :param Ext: File extension. Valid values: .m3u8, .ts, .mpd, .m4s, .mp4
+Note: this field may return `null`, indicating that no valid value was found.
+        :type Ext: str
+        """
+        self.Timeout = None
+        self.Ext = None
+
+
+    def _deserialize(self, params):
+        self.Timeout = params.get("Timeout")
+        self.Ext = params.get("Ext")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ChannelInfo(AbstractModel):
+    """Channel information.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Id: Channel ID.
+        :type Id: str
+        :param Name: Channel name.
+        :type Name: str
+        :param Protocol: Channel protocol.
+        :type Protocol: str
+        :param Points: Channel input and output.
+        :type Points: :class:`tencentcloud.mdp.v20200527.models.PointInfo`
+        :param CacheInfo: Cache configuration
+Note: this field may return `null`, indicating that no valid value was found.
+        :type CacheInfo: :class:`tencentcloud.mdp.v20200527.models.CacheInfo`
+        """
+        self.Id = None
+        self.Name = None
+        self.Protocol = None
+        self.Points = None
+        self.CacheInfo = None
+
+
+    def _deserialize(self, params):
+        self.Id = params.get("Id")
+        self.Name = params.get("Name")
+        self.Protocol = params.get("Protocol")
+        if params.get("Points") is not None:
+            self.Points = PointInfo()
+            self.Points._deserialize(params.get("Points"))
+        if params.get("CacheInfo") is not None:
+            self.CacheInfo = CacheInfo()
+            self.CacheInfo._deserialize(params.get("CacheInfo"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CreateStreamPackageChannelEndpointRequest(AbstractModel):
+    """CreateStreamPackageChannelEndpoint request structure.
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Id: Channel ID
+        :type Id: str
+        :param Name: Channel name
+        :type Name: str
+        :param AuthInfo: Authentication information
+        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.EndpointAuthInfo`
         """
-        :param Id: Channel ID.\n        :type Id: str\n        :param Name: Channel name.\n        :type Name: str\n        :param AuthInfo: Authentication information.\n        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.EndpointAuthInfo`\n        """
         self.Id = None
         self.Name = None
         self.AuthInfo = None
@@ -76,14 +158,18 @@ class CreateMediaPackageChannelEndpointRequest(AbstractModel):
         
 
 
-class CreateMediaPackageChannelEndpointResponse(AbstractModel):
-    """CreateMediaPackageChannelEndpoint response structure.
+class CreateStreamPackageChannelEndpointResponse(AbstractModel):
+    """CreateStreamPackageChannelEndpoint response structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param Info: Information of the created channel endpoint
+        :type Info: :class:`tencentcloud.mdp.v20200527.models.EndpointInfo`
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
         """
-        :param Info: The information of the created channel endpoint.\n        :type Info: :class:`tencentcloud.mdp.v20200527.models.EndpointInfo`\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.Info = None
         self.RequestId = None
 
@@ -95,21 +181,31 @@ class CreateMediaPackageChannelEndpointResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class CreateMediaPackageChannelRequest(AbstractModel):
-    """CreateMediaPackageChannel request structure.
+class CreateStreamPackageChannelRequest(AbstractModel):
+    """CreateStreamPackageChannel request structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param Name: Channel name
+        :type Name: str
+        :param Protocol: Channel protocol. Valid values: HLS, DASH
+        :type Protocol: str
+        :param CacheInfo: Cache configuration
+        :type CacheInfo: :class:`tencentcloud.mdp.v20200527.models.CacheInfo`
         """
-        :param Name: Channel name.\n        :type Name: str\n        :param Protocol: Channel protocol. Valid values: HLS, DASH.\n        :type Protocol: str\n        """
         self.Name = None
         self.Protocol = None
+        self.CacheInfo = None
 
 
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Protocol = params.get("Protocol")
+        if params.get("CacheInfo") is not None:
+            self.CacheInfo = CacheInfo()
+            self.CacheInfo._deserialize(params.get("CacheInfo"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -119,33 +215,35 @@ class CreateMediaPackageChannelRequest(AbstractModel):
         
 
 
-class CreateMediaPackageChannelResponse(AbstractModel):
-    """CreateMediaPackageChannel response structure.
+class CreateStreamPackageChannelResponse(AbstractModel):
+    """CreateStreamPackageChannel response structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
         """
-        :param Info: Channel information.\n        :type Info: :class:`tencentcloud.mdp.v20200527.models.ChannelInfo`\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
-        self.Info = None
         self.RequestId = None
 
 
     def _deserialize(self, params):
-        if params.get("Info") is not None:
-            self.Info = ChannelInfo()
-            self.Info._deserialize(params.get("Info"))
         self.RequestId = params.get("RequestId")
 
 
-class DeleteMediaPackageChannelEndpointsRequest(AbstractModel):
-    """DeleteMediaPackageChannelEndpoints request structure.
+class DeleteStreamPackageChannelEndpointsRequest(AbstractModel):
+    """DeleteStreamPackageChannelEndpoints request structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param Id: Channel ID
+        :type Id: str
+        :param Urls: List of the URLs of the endpoints to delete
+        :type Urls: list of str
         """
-        :param Id: Channel ID.\n        :type Id: str\n        :param Urls: The list of endpoint URLs.\n        :type Urls: list of str\n        """
         self.Id = None
         self.Urls = None
 
@@ -162,14 +260,16 @@ class DeleteMediaPackageChannelEndpointsRequest(AbstractModel):
         
 
 
-class DeleteMediaPackageChannelEndpointsResponse(AbstractModel):
-    """DeleteMediaPackageChannelEndpoints response structure.
+class DeleteStreamPackageChannelEndpointsResponse(AbstractModel):
+    """DeleteStreamPackageChannelEndpoints response structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -177,14 +277,16 @@ class DeleteMediaPackageChannelEndpointsResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class DeleteMediaPackageChannelsRequest(AbstractModel):
-    """DeleteMediaPackageChannels request structure.
+class DeleteStreamPackageChannelsRequest(AbstractModel):
+    """DeleteStreamPackageChannels request structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param Ids: List of the IDs of the channels to delete
+        :type Ids: list of str
         """
-        :param Ids: The ID list of channels to be deleted.\n        :type Ids: list of str\n        """
         self.Ids = None
 
 
@@ -199,14 +301,20 @@ class DeleteMediaPackageChannelsRequest(AbstractModel):
         
 
 
-class DeleteMediaPackageChannelsResponse(AbstractModel):
-    """DeleteMediaPackageChannels response structure.
+class DeleteStreamPackageChannelsResponse(AbstractModel):
+    """DeleteStreamPackageChannels response structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param SuccessInfos: List of the information of successfully deleted channels
+        :type SuccessInfos: list of ChannelInfo
+        :param FailInfos: List of the information of the channels that failed to be deleted
+        :type FailInfos: list of ChannelInfo
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
         """
-        :param SuccessInfos: The information list of channels that have been deleted.\n        :type SuccessInfos: list of ChannelInfo\n        :param FailInfos: The information list of channels that failed to be deleted.\n        :type FailInfos: list of ChannelInfo\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.SuccessInfos = None
         self.FailInfos = None
         self.RequestId = None
@@ -228,14 +336,16 @@ class DeleteMediaPackageChannelsResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class DescribeMediaPackageChannelRequest(AbstractModel):
-    """DescribeMediaPackageChannel request structure.
+class DescribeStreamPackageChannelRequest(AbstractModel):
+    """DescribeStreamPackageChannel request structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param Id: Channel ID
+        :type Id: str
         """
-        :param Id: Channel ID.\n        :type Id: str\n        """
         self.Id = None
 
 
@@ -250,14 +360,18 @@ class DescribeMediaPackageChannelRequest(AbstractModel):
         
 
 
-class DescribeMediaPackageChannelResponse(AbstractModel):
-    """DescribeMediaPackageChannel response structure.
+class DescribeStreamPackageChannelResponse(AbstractModel):
+    """DescribeStreamPackageChannel response structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param Info: Channel information
+        :type Info: :class:`tencentcloud.mdp.v20200527.models.ChannelInfo`
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
         """
-        :param Info: Channel information.\n        :type Info: :class:`tencentcloud.mdp.v20200527.models.ChannelInfo`\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.Info = None
         self.RequestId = None
 
@@ -269,14 +383,18 @@ class DescribeMediaPackageChannelResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class DescribeMediaPackageChannelsRequest(AbstractModel):
-    """DescribeMediaPackageChannels request structure.
+class DescribeStreamPackageChannelsRequest(AbstractModel):
+    """DescribeStreamPackageChannels request structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param PageNum: Page number. Value range: [1, 1000]
+        :type PageNum: int
+        :param PageSize: Number of entries per page. Value range: [1, 1000]
+        :type PageSize: int
         """
-        :param PageNum: Page number. Value range: [1, 1000].\n        :type PageNum: int\n        :param PageSize: The size of each page. Value range: [1, 1000].\n        :type PageSize: int\n        """
         self.PageNum = None
         self.PageSize = None
 
@@ -293,15 +411,27 @@ class DescribeMediaPackageChannelsRequest(AbstractModel):
         
 
 
-class DescribeMediaPackageChannelsResponse(AbstractModel):
-    """DescribeMediaPackageChannels response structure.
+class DescribeStreamPackageChannelsResponse(AbstractModel):
+    """DescribeStreamPackageChannels response structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param Infos: List of channel information
+Note: this field may return `null`, indicating that no valid value was found.
+        :type Infos: list of ChannelInfo
+        :param PageNum: Page number
+        :type PageNum: int
+        :param PageSize: Number of entries per page
+        :type PageSize: int
+        :param TotalNum: Total number of entries
+        :type TotalNum: int
+        :param TotalPage: Total number of pages
+        :type TotalPage: int
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
         """
-        :param Infos: The list of channel outputs.
-Note: this field may return null, indicating that no valid values can be obtained.\n        :type Infos: list of ChannelInfo\n        :param PageNum: Page number.\n        :type PageNum: int\n        :param PageSize: The size of each page.\n        :type PageSize: int\n        :param TotalNum: Total number.\n        :type TotalNum: int\n        :param TotalPage: Total number of pages.\n        :type TotalPage: int\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.Infos = None
         self.PageNum = None
         self.PageSize = None
@@ -330,11 +460,17 @@ class EndpointAuthInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param WhiteIpList: The security group allowlist in CIDR format.
-Note: this field may return null, indicating that no valid values can be obtained.\n        :type WhiteIpList: list of str\n        :param BlackIpList: The security group blocklist in CIDR format.
-Note: this field may return null, indicating that no valid values can be obtained.\n        :type BlackIpList: list of str\n        :param AuthKey: The authentication key. Its value is same as `X-TENCENT-PACKAGE` set in the HTTP request header.
-Note: this field may return null, indicating that no valid values can be obtained.\n        :type AuthKey: str\n        """
+Note: this field may return null, indicating that no valid values can be obtained.
+        :type WhiteIpList: list of str
+        :param BlackIpList: The security group blocklist in CIDR format.
+Note: this field may return null, indicating that no valid values can be obtained.
+        :type BlackIpList: list of str
+        :param AuthKey: The authentication key. Its value is same as `X-TENCENT-PACKAGE` set in the HTTP request header.
+Note: this field may return null, indicating that no valid values can be obtained.
+        :type AuthKey: str
+        """
         self.WhiteIpList = None
         self.BlackIpList = None
         self.AuthKey = None
@@ -359,8 +495,14 @@ class EndpointInfo(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Name: Endpoint name.
+        :type Name: str
+        :param Url: Endpoint URL.
+        :type Url: str
+        :param AuthInfo: Endpoint authentication information.
+        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.EndpointAuthInfo`
         """
-        :param Name: Endpoint name.\n        :type Name: str\n        :param Url: Endpoint URL.\n        :type Url: str\n        :param AuthInfo: Endpoint authentication information.\n        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.EndpointAuthInfo`\n        """
         self.Name = None
         self.Url = None
         self.AuthInfo = None
@@ -387,10 +529,14 @@ class InputAuthInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Username: Username.
-Note: this field may return null, indicating that no valid values can be obtained.\n        :type Username: str\n        :param Password: Password.
-Note: this field may return null, indicating that no valid values can be obtained.\n        :type Password: str\n        """
+Note: this field may return null, indicating that no valid values can be obtained.
+        :type Username: str
+        :param Password: Password.
+Note: this field may return null, indicating that no valid values can be obtained.
+        :type Password: str
+        """
         self.Username = None
         self.Password = None
 
@@ -413,9 +559,13 @@ class InputInfo(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Url: Channel input URL.
-Note: this field may return null, indicating that no valid values can be obtained.\n        :type Url: str\n        :param AuthInfo: Channel input authentication information.\n        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.InputAuthInfo`\n        """
+Note: this field may return null, indicating that no valid values can be obtained.
+        :type Url: str
+        :param AuthInfo: Channel input authentication information.
+        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.InputAuthInfo`
+        """
         self.Url = None
         self.AuthInfo = None
 
@@ -434,14 +584,22 @@ Note: this field may return null, indicating that no valid values can be obtaine
         
 
 
-class ModifyMediaPackageChannelEndpointRequest(AbstractModel):
-    """ModifyMediaPackageChannelEndpoint request structure.
+class ModifyStreamPackageChannelEndpointRequest(AbstractModel):
+    """ModifyStreamPackageChannelEndpoint request structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param Id: Channel ID
+        :type Id: str
+        :param Url: Channel endpoint URL
+        :type Url: str
+        :param Name: New endpoint name
+        :type Name: str
+        :param AuthInfo: New channel authentication information
+        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.EndpointAuthInfo`
         """
-        :param Id: Channel ID.\n        :type Id: str\n        :param Url: Channel endpoint URL.\n        :type Url: str\n        :param Name: The channel name after modification.\n        :type Name: str\n        :param AuthInfo: The channel authentication after modification.\n        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.EndpointAuthInfo`\n        """
         self.Id = None
         self.Url = None
         self.Name = None
@@ -464,14 +622,16 @@ class ModifyMediaPackageChannelEndpointRequest(AbstractModel):
         
 
 
-class ModifyMediaPackageChannelEndpointResponse(AbstractModel):
-    """ModifyMediaPackageChannelEndpoint response structure.
+class ModifyStreamPackageChannelEndpointResponse(AbstractModel):
+    """ModifyStreamPackageChannelEndpoint response structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -479,16 +639,22 @@ class ModifyMediaPackageChannelEndpointResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class ModifyMediaPackageChannelInputAuthInfoRequest(AbstractModel):
-    """ModifyMediaPackageChannelInputAuthInfo request structure.
+class ModifyStreamPackageChannelInputAuthInfoRequest(AbstractModel):
+    """ModifyStreamPackageChannelInputAuthInfo request structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param Id: Channel ID
+        :type Id: str
+        :param Url: Channel input URL
+        :type Url: str
+        :param ActionType: Authentication configuration. Valid values: `CLOSE`, `UPDATE`
+`CLOSE`: disable authentication
+`UPDATE`: update authentication information
+        :type ActionType: str
         """
-        :param Id: Channel ID.\n        :type Id: str\n        :param Url: Channel input URL.\n        :type Url: str\n        :param ActionType: Authentication configuration type. Valid values: CLOSE, UPDATE.
-CLOSE: disable authentication.
-UPDATE: update authentication.\n        :type ActionType: str\n        """
         self.Id = None
         self.Url = None
         self.ActionType = None
@@ -507,14 +673,18 @@ UPDATE: update authentication.\n        :type ActionType: str\n        """
         
 
 
-class ModifyMediaPackageChannelInputAuthInfoResponse(AbstractModel):
-    """ModifyMediaPackageChannelInputAuthInfo response structure.
+class ModifyStreamPackageChannelInputAuthInfoResponse(AbstractModel):
+    """ModifyStreamPackageChannelInputAuthInfo response structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param AuthInfo: Channel input authentication information
+        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.InputAuthInfo`
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
         """
-        :param AuthInfo: Channel input authentication information.\n        :type AuthInfo: :class:`tencentcloud.mdp.v20200527.models.InputAuthInfo`\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.AuthInfo = None
         self.RequestId = None
 
@@ -526,23 +696,35 @@ class ModifyMediaPackageChannelInputAuthInfoResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class ModifyMediaPackageChannelRequest(AbstractModel):
-    """ModifyMediaPackageChannel request structure.
+class ModifyStreamPackageChannelRequest(AbstractModel):
+    """ModifyStreamPackageChannel request structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param Id: Channel ID
+        :type Id: str
+        :param Name: New channel name
+        :type Name: str
+        :param Protocol: New channel protocol. Valid values: HLS, DASH
+        :type Protocol: str
+        :param CacheInfo: Cache configuration
+        :type CacheInfo: :class:`tencentcloud.mdp.v20200527.models.CacheInfo`
         """
-        :param Id: Channel ID.\n        :type Id: str\n        :param Name: The channel name after modification.\n        :type Name: str\n        :param Protocol: The channel protocol after modification. Valid values: HLS, DASH.\n        :type Protocol: str\n        """
         self.Id = None
         self.Name = None
         self.Protocol = None
+        self.CacheInfo = None
 
 
     def _deserialize(self, params):
         self.Id = params.get("Id")
         self.Name = params.get("Name")
         self.Protocol = params.get("Protocol")
+        if params.get("CacheInfo") is not None:
+            self.CacheInfo = CacheInfo()
+            self.CacheInfo._deserialize(params.get("CacheInfo"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -552,14 +734,16 @@ class ModifyMediaPackageChannelRequest(AbstractModel):
         
 
 
-class ModifyMediaPackageChannelResponse(AbstractModel):
-    """ModifyMediaPackageChannel response structure.
+class ModifyStreamPackageChannelResponse(AbstractModel):
+    """ModifyStreamPackageChannel response structure.
 
     """
 
     def __init__(self):
+        r"""
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -573,9 +757,13 @@ class PointInfo(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Inputs: Channel input list.
+        :type Inputs: list of InputInfo
+        :param Endpoints: Channel output list.
+Note: this field may return null, indicating that no valid values can be obtained.
+        :type Endpoints: list of EndpointInfo
         """
-        :param Inputs: Channel input list.\n        :type Inputs: list of InputInfo\n        :param Endpoints: Channel output list.
-Note: this field may return null, indicating that no valid values can be obtained.\n        :type Endpoints: list of EndpointInfo\n        """
         self.Inputs = None
         self.Endpoints = None
 
